==> prestashop_1.3.5.0.zip: prestashop/modules/statsregistrations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Comptes clients';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_54c04cc0d869c12ea9f5426466d40fea'] = 'Affiche l\'évolution des créations de compte';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visiteurs bloqués à la phase d\'inscription :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_0d298316c16a0bbdb74d50ead21590b4'] = 'Visiteurs ayant passé une commande dès leur inscription :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total de comptes créés :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Nombre de comptes créés';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_15d820295ae2d9d7e6d53e1ed9714273'] = 'Le nombre d\'inscrits en lui-même n\'est pas important. Il vous permet surtout d\'apprécier son évolution sur une période plus ou moins longue. ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Comment agir sur l\'évolution des inscriptions ?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_2d8c349a97131b417bf7da166afb17bd'] = 'Si vous laissez votre boutique tourner sans rien changer, le nombre d\'inscriptions devrait être stable ou baisser légèrement.  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_bf88699f842b6e63e0568ed0e71c68b7'] = 'Une forte croissance ou une forte baisse montre donc probablement un changement sur votre boutique. C\'est pourquoi vous devez l\'identifier de manière à pouvoir revenir sur vos pas au cas où ce changement fait décroître le nombre d\'inscriptions, ou au contraire continuer dans cette voie si celui-ci se trouve avantageux.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_7f93ad00e5438305b72efd723da48cdb'] = 'Différents modificateurs sont possibles :  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_c22f6af88c5ec8dcdba70e4fa394b08e'] = 'Une campagne de publicité peut attirer un grand nombre de visiteurs. De plus, une campagne de pub bien ciblée peut s\'avérer plus efficace qu\'une publicité à grande échelle.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_d140e86c9fd44c00ed1df75b92ce8115'] = 'Les promotions, soldes ou jeux-concours attirent fortement l\'attention et la curiosité des visiteurs ; permettant non seulement l\'animation de votre boutique, mais aussi l\'augmentation de son trafic. De cette manière, vous pouvez pousser un acheteur \"spontané\" à se lancer.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_97d6defbec1f8cd01e8219da3e917a0b'] = 'Esthétique : un changement de thème peut rebuter les visiteurs. L\'orthographe et la clarté sont également à soigner. ';

==> prestashop_1.4.0.7.zip: prestashop/modules/statsregistrations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Comptes clients';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_54c04cc0d869c12ea9f5426466d40fea'] = 'Affiche l\'évolution des créations de compte';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visiteurs bloqués à la phase d\'inscription :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_0d298316c16a0bbdb74d50ead21590b4'] = 'Visiteurs ayant passé une commande dès leur inscription :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total de comptes créés :';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'Export CSV';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Nombre de comptes créés';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_15d820295ae2d9d7e6d53e1ed9714273'] = 'Le nombre d\'inscrits en lui-même n\'est pas important. Il vous permet surtout d\'apprécier son évolution sur une période plus ou moins longue. ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Comment agir sur l\'évolution des inscriptions ?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_2d8c349a97131b417bf7da166afb17bd'] = 'Si vous laissez votre boutique tourner sans rien changer, le nombre d\'inscriptions devrait être stable ou baisser légèrement.  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_bf88699f842b6e63e0568ed0e71c68b7'] = 'Une forte croissance ou une forte baisse montre donc probablement un changement sur votre boutique. C\'est pourquoi vous devez l\'identifier de manière à pouvoir revenir sur vos pas au cas où ce changement fait décroître le nombre d\'inscriptions, ou au contraire continuer dans cette voie si celui-ci se trouve avantageux.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_7f93ad00e5438305b72efd723da48cdb'] = 'Différents modificateurs sont possibles :  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_c22f6af88c5ec8dcdba70e4fa394b08e'] = 'Une campagne de publicité peut attirer un grand nombre de visiteurs. De plus, une campagne de pub bien ciblée peut s\'avérer plus efficace qu\'une publicité à grande échelle.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_d140e86c9fd44c00ed1df75b92ce8115'] = 'Les promotions, soldes ou jeux-concours attirent fortement l\'attention et la curiosité des visiteurs ; permettant non seulement l\'animation de votre boutique, mais aussi l\'augmentation de son trafic. De cette manière, vous pouvez pousser un acheteur \"spontané\" à se lancer.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_97d6defbec1f8cd01e8219da3e917a0b'] = 'Esthétique : un changement de thème peut rebuter les visiteurs. L\'orthographe et la clarté sont également à soigner. ';
